@@ -186,7 +186,7 @@ class GPUPricesIn(BaseModel):
 
 class UserGPUPrices(BaseModel):
     user_id: str
-    prices: dict[str, dict[GPUType, GPUPrices]]
+    prices: Dict[str, Dict[GPUType, GPUPrices]]
 
 
 class Transaction(BaseModel):
@@ -510,11 +510,13 @@ class InferenceDeploymentInitialWorkersConfig(BaseModel):
     use_cloudburst: Optional[bool] = False
     on_prem_node_ids: Optional[List[str]] = None
     expand_gpu_types: Optional[bool] = True
+    max_workers: Optional[int] = 100
 
 
 class InferenceDeploymentAutoscalingStrategy(str, Enum):
     ttft_latency_sec = "ttft_latency_sec"
     rps_per_worker = "rps_per_worker"
+    e2e_latency_sec = "e2e_latency_sec"
 
 
 class InferenceDeploymentAutoscalingConfig(BaseModel):
@@ -597,7 +599,13 @@ class InferenceDeploymentIn(BaseModel):
     controller_on_prem_config: Optional[InferenceControllerOnPremConfig] = None
 
     llm_loras: Optional[List[LLMLoraConfig]] = []
+
+    # Only llm related args (vllm)
     max_model_len: Optional[int] = None
+    throughput_optimized: Optional[bool] = False
+
+    # Agentic related args
+    agentic_deployment: Optional[bool] = False
 
     def __init__(self, **data: Any):
         # Validate that controller_cloud_config or controller_on_prem_config is provided
@@ -629,7 +637,7 @@ class InferenceDeploymentPriceEstimationIn(BaseModel):
     gpu: Optional[List[GpuTypeCount]] = None
     region: Optional[List[str]] = None
 
-    number_of_workers: int = Field(1, gt=0)
+    # number_of_workers: int = Field(1, gt=0)
 
     @model_validator(mode="after")
     def check_fields(self):
@@ -698,6 +706,10 @@ default_engine_strategy_map = {
             InferenceDeploymentEngine.vllm,
             InferenceDeploymentAutoscalingStrategy.rps_per_worker,
         ),
+        (
+            InferenceDeploymentEngine.vllm,
+            InferenceDeploymentAutoscalingStrategy.e2e_latency_sec,
+        ),
         (
             InferenceDeploymentEngine.nim,
             InferenceDeploymentAutoscalingStrategy.ttft_latency_sec,
@@ -784,7 +796,7 @@ class FinetuningIn(BaseModel):
     job_name: Optional[str] = None
     ft_type: FinetuningType = FinetuningType.CLM
     model: str
-    base_model: str
+    base_model: Optional[str] = None
     use_recipes: Optional[bool] = False
     artifacts_storage: Optional[str] = None
 
@@ -1106,3 +1118,23 @@ class DNSGetCertOut(BaseModel):
     cert_file: str
     key_file: str
     cert_chain_file: str
+
+
+#### Fixed Templates ####
+
+
+class FixedTemplateInferenceDB(BaseModel):
+    id: str
+    name: str
+    config: InferenceDeploymentIn
+
+
+class FixedTemplateFinetuneDB(BaseModel):
+    id: str
+    name: str
+    config: FinetuningIn
+
+
+class EditDevUserIn(BaseModel):
+    user_status: Optional[str] = ""
+    jc_status: Optional[str] = ""
