@@ -157,6 +157,13 @@ class GPUType(str, Enum):
     H100_80GB_PCIE_NVLINK = "H100_80GB_PCIE_NVLINK"  # PCIE with NVLINK
     H100_80GB_SXM_NVLINK = "H100_80GB_SXM_NVLINK"  # SXM with NVLINK
 
+    # H200
+    H200 = "H200"
+    H200_PCIE = "H200_PCIE"  # PCIE
+    H200_SXM = "H200_SXM"  # SXM
+    H200_PCIE_NVLINK = "H200_PCIE_NVLINK"  # PCIE with NVLINK
+    H200_SXM_NVLINK = "H200_SXM_NVLINK"  # SXM with NVLINK
+
     GH201 = "GH201"
     K80 = "K80"
     L4 = "L4"
