@@ -10,7 +10,7 @@ class SGFinetuneParams(BaseModel):
     """
 
     model: str = Field(None, title="Model name")
-    job_name: str = Field("", title="ScaleGen job name")
+    job_name: Optional[str] = Field("", title="ScaleGen job name")
     project_name: Optional[str] = Field("ScaleGen Project", title="Output directory")
     data_path: str = Field("data", title="Data path")
     push_to_hub: bool = Field(False, title="Push to hub")
@@ -108,7 +108,9 @@ class LLMTrainingParams(SGFinetuneParams):
     eval_steps: Optional[int] = Field(None, title="Save steps to use")
     load_best_model_at_end: bool = Field(True, title="Load the best model at the end")
     resume_from_checkpoint: Optional[str] = Field(None, title="Checkpoint dir")
-    user_checkpoint_dir: str = Field("", title="User checkpoint dir to resume from")
+    user_checkpoint_dir: Optional[str] = Field(
+        "", title="User checkpoint dir to resume from"
+    )
     neftune_noise_alpha: Optional[float] = Field(
         None,
         title="If not None, this will activate NEFTune noise embeddings. This can drastically improve model performance for instruction fine-tuning.",
@@ -167,12 +169,19 @@ class LLMTrainingParams(SGFinetuneParams):
 
     # column mappings
     prompt_text_column: Optional[str] = Field(None, title="Prompt text column")
-    text_column: str = Field("text", title="Text column")
+    text_column: str = Field("text", title="Text column", strict=False)
     rejected_text_column: Optional[str] = Field(None, title="Rejected text column")
 
     # unsloth
     use_unsloth: bool = Field(False, title="Use unsloth")
 
+    def __init__(self, **data):
+
+        if not data.get("seed"):
+            data["seed"] = 42
+
+        super().__init__(**data)
+
 
 class SentenceTransformersParams(SGFinetuneParams):
     # data params
