@@ -454,7 +454,7 @@ def create_inf_dep(
 @click.option(
     "--autoscaling_strategy",
     cls=CategorizedMutuallyExclusiveOption,
-    type=click.Choice(["rps_per_worker", "ttft_latency_sec"]),
+    type=click.Choice(["rps_per_worker", "ttft_latency_sec", "e2e_latency_sec"]),
     required=False,
     default=DEFAULT_AUTOSCALING_CONFIG.autoscaling_strategy,
     help="Autoscaling strategy to use.",
@@ -517,7 +517,7 @@ def create_inf_dep(
     mutually_exclusive=["min_throughput_rate"],
 )
 @click.option(
-    "--expand_gpu_types",
+    "--strict_gpu_types",
     cls=CategorizedMutuallyExclusiveOption,
     is_flag=True,
     help="For A100, H100 GPUs, this option when set includes PCIE, SXM and NVLINK variants.",
@@ -626,6 +626,12 @@ def create_inf_dep(
     required=False,
     help="Max Sequence length to be used by the inference engine",
 )
+@click.option(
+    "--throughput_optimized",
+    is_flag=True,
+    required=False,
+    help="Enable throughput optimization",
+)
 @click.option("-f", "--force", is_flag=True)
 @click.option("-q", "--quiet", is_flag=True)
 def create_impl(**inference_kwargs: Any):
@@ -716,11 +722,9 @@ def create_impl(**inference_kwargs: Any):
             "min_workers": inference_kwargs["min_workers"],
             "initial_workers_gpu": inference_kwargs["initial_workers_gpu_type"],
             "initial_workers_gpu_num": inference_kwargs["initial_workers_gpu_num"],
-            "use_same_gpus_when_scaling": inference_kwargs[
-                "use_same_gpus_when_scaling"
-            ],
+            "use_other_gpus": not inference_kwargs["use_same_gpus_when_scaling"],
             "instance_types": inference_kwargs["instance_types"],
-            "expand_gpu_types": inference_kwargs["expand_gpu_types"],
+            "expand_gpu_types": not bool(inference_kwargs["strict_gpu_types"]),
         },
         "autoscaling_config": {
             "enable_fast_autoscaling": inference_kwargs["enable_fast_autoscaling"],
@@ -749,6 +753,7 @@ def create_impl(**inference_kwargs: Any):
         "max_price_per_hour": inference_kwargs["max_price_per_hour"],
         "min_throughput_rate": inference_kwargs["min_throughput_rate"],
         "max_model_len": inference_kwargs["max_model_len"],
+        "throughput_optimized": inference_kwargs["throughput_optimized"],
     }
 
     inf_dep_req_data = InferenceDeploymentIn(**data)
@@ -863,14 +868,15 @@ def start_impl(inf_id: str, force: bool, quiet: bool):
 
 
 @infer.command("stop")
+@click.option("-f", "--force", is_flag=True)
 @click.argument("inf_id", type=click.STRING, required=True)
-def stop_impl(inf_id: str):
+def stop_impl(inf_id: str, force: bool = False):
     """
     Allows user to make the InferenceDeployment go to INACTIVE state
     """
 
     dep = get_deployment(inf_id)
-    if dep["status"] != InferenceDeploymentStatus.ACTIVE:
+    if dep["status"] != InferenceDeploymentStatus.ACTIVE and not force:
         click.echo(
             click.style(f"Deployment with inf_id {inf_id} is not active", fg="red"),
             err=True,
@@ -879,7 +885,9 @@ def stop_impl(inf_id: str):
 
     console = Console()
     with console.status(f"[bold green]Scaling deployment with inf_id {inf_id}...") as _:
-        resp = send_request("POST", f"/sg_inf/{inf_id}/scale/zero")
+        resp = send_request(
+            "POST", f"/sg_inf/{inf_id}/scale/zero", params={"force": force}
+        )
 
     if resp.status_code == 200:
         resp_data = resp.json()
